I128CO

Struct I128CO 

pub struct I128CO { /* private fields */ }

Implementations

Source

impl I128CO

pub const fn try_new(start: i128, end_excl: i128) -> Option<Self>

pub const unsafe fn new_unchecked(start: i128, end_excl: i128) -> Self

pub const fn start(self) -> i128

pub const fn end_excl(self) -> i128

pub const fn end_incl(self) -> i128

pub const fn len(self) -> u128

pub const fn contains(self, x: i128) -> bool

pub const fn iter(self) -> Range<i128>

pub const fn to_range(self) -> Range<i128>

pub const fn intersects(self, other: Self) -> bool

pub const fn is_adjacent(self, other: Self) -> bool

pub const fn is_contiguous_with(self, other: Self) -> bool

Source

impl I128CO

pub const fn intersection(self, other: Self) -> Option<Self>

Returns the intersection of two intervals.

If the intervals do not overlap, returns None.

pub const fn convex_hull(self, other: Self) -> Self

Returns the convex hull (smallest interval containing both) of two intervals.

Always returns a valid I128CO.

pub const fn between(self, other: Self) -> Option<Self>

Returns the interval strictly between two intervals.

If the intervals are contiguous or overlap, returns None.

pub const fn union(self, other: Self) -> OneTwo<Self>

Returns the union of two intervals.

  • If intervals are contiguous or overlapping, returns One containing the merged interval.
  • Otherwise, returns Two containing both intervals in ascending order.
pub const fn difference(self, other: Self) -> ZeroOneTwo<Self>

Returns the difference of two intervals (self - other).

  • If no overlap, returns One(self).
  • If partial overlap, returns One or Two depending on remaining segments.
  • If fully contained, returns Zero.
pub const fn symmetric_difference(self, other: Self) -> ZeroOneTwo<Self>

Returns the symmetric difference of two intervals.

Equivalent to (self - other) ∪ (other - self).

  • If intervals do not overlap, returns Two(self, other) in order.
  • If intervals partially overlap, returns remaining non-overlapping segments as One or Two.
Source

impl I128CO

pub const fn checked_minkowski_add(self, other: Self) -> Option<Self>

pub const fn checked_minkowski_sub(self, other: Self) -> Option<Self>

pub const fn checked_minkowski_mul(self, other: Self) -> Option<Self>

pub const fn checked_minkowski_div(self, other: Self) -> Option<Self>

Source

impl I128CO

pub const fn checked_minkowski_add_n(self, n: i128) -> Option<Self>

pub const fn checked_minkowski_sub_n(self, n: i128) -> Option<Self>

pub const fn checked_minkowski_mul_n(self, n: i128) -> Option<Self>

pub const fn checked_minkowski_div_n(self, n: i128) -> Option<Self>

Source

impl I128CO

pub const fn saturating_minkowski_add(self, other: Self) -> Option<Self>

pub const fn saturating_minkowski_sub(self, other: Self) -> Option<Self>

pub const fn saturating_minkowski_mul(self, other: Self) -> Option<Self>

pub const fn saturating_minkowski_div(self, other: Self) -> Option<Self>

Source

impl I128CO

pub const fn saturating_minkowski_add_n(self, n: i128) -> Option<Self>

pub const fn saturating_minkowski_sub_n(self, n: i128) -> Option<Self>

pub const fn saturating_minkowski_mul_n(self, n: i128) -> Option<Self>

pub const fn saturating_minkowski_div_n(self, n: i128) -> Option<Self>